@@ -20,7 +20,6 @@ from .config import (
     PYTHON_ENCODING,
     ANSI,
     IS_TTY,
-    SHOW_PROGRESS,
     TERM_WIDTH,
     OUTPUT_DIR,
     SOURCES_DIR_NAME,
@@ -519,6 +518,7 @@ def printable_folder_status(name: str, folder: Dict) -> str:
 
 @enforce_types
 def printable_dependency_version(name: str, dependency: Dict) -> str:
+    version = None
     if dependency['enabled']:
         if dependency['is_valid']:
             color, symbol, note, version = 'green', '√', 'valid', ''
